Learn R Programming

ABCDscores (version 6.1.0)

ABCDscores-package: ABCDscores: Summary Scores of the Adolescent Brain Cognitive Development (ABCD) Study

Description

Provides functions to compute summary scores (besides proprietary ones) reported in the tabulated data resource that is released by the Adolescent Brain Cognitive Development (ABCD) study.

Arguments

Author

Maintainer: Le Zhang dairc.service@gmail.com (ORCID)

Authors:

References

Zhang, L., Celhay, O., Das, B., Berman, S., Ziemer, L. R., Smith, C. J., Dale, A. M., & Linkersdörfer, J. (2025). ABCDscores: An R package for computing summary scores in the ABCD Study. bioRxiv. tools:::Rd_expr_doi("10.1101/2025.09.04.674066")

See Also