Computes the summary score fc_p_fes__intelcult_nm
(Family Environment Scale [Parent] (Intellectual and cultural): Number
missing)
Summarized variables:
fc_p_fes__intelcult_001
fc_p_fes__intelcult_002
fc_p_fes__intelcult_003
fc_p_fes__intelcult_004
fc_p_fes__intelcult_005
fc_p_fes__intelcult_006
fc_p_fes__intelcult_007
fc_p_fes__intelcult_008
fc_p_fes__intelcult_009
Excluded values: none
compute_fc_p_fes__intelcult_nm(
data,
name = "fc_p_fes__intelcult_nm",
combine = TRUE
)tbl. The input data frame with the summary score appended as a new column.
tbl. Data frame containing the columns to be summarized.
character. Name of the summary score. Default is the name in the description.
logical. If TRUE, the summary score is appended to the
input data frame. If FALSE, the summary score is returned as a separate
data frame. Default is TRUE.
compute_fc_p_fes__intelcult_mean()