Computes the summary score fc_p_nce__isc_nm
(Neighborhood Collective Efficacy [Parent] (Informal social control): Number
missing)
Summarized variables:
fc_p_nce__isc_001
fc_p_nce__isc_002
fc_p_nce__isc_003
fc_p_nce__isc_004
fc_p_nce__isc_005
Excluded values:
777
compute_fc_p_nce__isc_nm(data, name = "fc_p_nce__isc_nm", combine = TRUE)tbl. The input data frame with the summary score appended as a new column.
tbl. Data frame containing the columns to be summarized.
character. Name of the summary score. Default is the name in the description.
logical. If TRUE, the summary score is appended to the
input data frame. If FALSE, the summary score is returned as a separate
data frame. Default is TRUE.
compute_fc_p_nce__isc_mean()