Computes the summary score fc_p_nsc__ns_nm
(Neighborhood Safety & Crime [Parent] (Neighborhood safety): Number missing)
Summarized variables:
fc_p_nsc__ns_001
fc_p_nsc__ns_002
fc_p_nsc__ns_003
Excluded values:
777
999
compute_fc_p_nsc__ns_nm(data, name = "fc_p_nsc__ns_nm", combine = TRUE)tbl. The input data frame with the summary score appended as a new column.
tbl. Data frame containing the columns to be summarized.
character. Name of the summary score. Default is the name in the description.
logical. If TRUE, the summary score is appended to the
input data frame. If FALSE, the summary score is returned as a separate
data frame. Default is TRUE.
compute_fc_p_nsc__ns_mean()