Computes the summary score fc_p_vs__famil_nm__v01
(Values Scale [Parent] (Familism): Number missing - Baseline to Year 5)
Summarized variables:
fc_p_vs__supp_001
fc_p_vs__supp_002
fc_p_vs__supp_003
fc_p_vs__supp_004
fc_p_vs__supp_005
fc_p_vs__supp_006
fc_p_vs__ref_001
fc_p_vs__ref_002
fc_p_vs__ref_003
fc_p_vs__ref_004
fc_p_vs__ref_005
fc_p_vs__obl_001
fc_p_vs__obl_002
fc_p_vs__obl_003
fc_p_vs__obl_004
fc_p_vs__obl_005
Excluded values:
777
999
compute_fc_p_vs__famil_nm(
data,
name = "fc_p_vs__famil_nm",
exclude = c("777", "999"),
combine = TRUE
)tbl. The input data frame with the summary score appended as a new column.
tbl. Data frame containing the columns to be summarized.
character. Name of the summary score. Default is the name in the description.
character vector. Values to be excluded from the summary score calculation.
logical. If TRUE, the summary score is appended to the
input data frame. If FALSE, the summary score is returned as a separate
data frame. Default is TRUE.
compute_fc_p_vs__famil_mean()