Learn R Programming

ABCDscores (version 6.1.0)

compute_fc_p_vs_all: Compute all the fc_p_vs summary scores

Description

This is a high-level function that computes all summary scores in this table. Make sure the data contains all the necessary columns.

Usage

compute_fc_p_vs_all(data)

Value

tbl. The input data frame with the summary scores appended as new columns.

Arguments

data

tbl, Dataframe containing the columns to be summarized.

Examples

Run this code
if (FALSE) {
compute_fc_p_vs_all(data)
}

Run the code above in your browser using DataLab