Computes the summary score fc_y_pm_nm
(Parental Monitoring [Youth]: Number missing)
Summarized variables:
fc_y_pm_001
fc_y_pm_002
fc_y_pm_003
fc_y_pm_004
fc_y_pm_005
Excluded values:
777
compute_fc_y_pm_nm(data, name = "fc_y_pm_nm", combine = TRUE)tbl. The input data frame with the summary score appended as a new column.
tbl. Data frame containing the columns to be summarized.
character. Name of the summary score. Default is the name in the description.
logical. If TRUE, the summary score is appended to the
input data frame. If FALSE, the summary score is returned as a separate
data frame. Default is TRUE.
compute_fc_y_pm_mean()