Computes the summary score fc_y_pnh_nm
(Peer Network Health [Youth]: Number missing)
Summarized variables:
fc_y_pnh_001
fc_y_pnh_002
fc_y_pnh_002__01
fc_y_pnh_003
fc_y_pnh_003__01
Excluded values: none
compute_fc_y_pnh_nm(data, name = "fc_y_pnh_nm", combine = TRUE)tbl. The input data frame with the summary score appended as a new column.
tbl. Data frame containing the columns to be summarized.
character. Name of the summary score. Default is the name in the description.
logical. If TRUE, the summary score is appended to the
input data frame. If FALSE, the summary score is returned as a separate
data frame. Default is TRUE.
compute_fc_y_pnh_sum()