Computes the summary score fc_y_vs__obl_nm
(Values Scale [Youth] (Family obligation): Number
missing)
Summarized variables:
fc_y_vs__obl_001
fc_y_vs__obl_002
fc_y_vs__obl_003
fc_y_vs__obl_004
fc_y_vs__obl_005
Excluded values: none
compute_fc_y_vs__obl_nm(data, name = "fc_y_vs__obl_nm", combine = TRUE)tbl. The input data frame with the summary score appended as a new column.
tbl. Data frame containing the columns to be summarized.
character. Name of the summary score. Default is the name in the description.
logical. If TRUE, the summary score is appended to the
input data frame. If FALSE, the summary score is returned as a separate
data frame. Default is TRUE.
compute_fc_y_vs__obl_mean()