Computes the summary score fc_y_wpss_nm
(Wills Problem Solving Scale [Youth]: Number missing)
Summarized variables:
fc_y_wpss_001
fc_y_wpss_002
fc_y_wpss_003
fc_y_wpss_004
fc_y_wpss_005
fc_y_wpss_006
Excluded values: none
compute_fc_y_wpss_nm(data, name = "fc_y_wpss_nm", combine = TRUE)tbl. The input data frame with the summary score appended as a new column.
tbl. Data frame containing the columns to be summarized.
character. Name of the summary score. Default is the name in the description.
logical. If TRUE, the summary score is appended to the
input data frame. If FALSE, the summary score is returned as a separate
data frame. Default is TRUE.
compute_fc_y_wpss_mean()