Learn R Programming

ABCDscores (version 6.1.0)

compute_mh_p_ders__distract_nm: Compute "Difficulties in Emotion Regulation Scale [Parent] (Distracted): Number missing"

Description

Computes the summary score mh_p_ders__distract_nm Difficulties in Emotion Regulation Scale [Parent] (Distracted): Number missing

  • Summarized variables:

    • mh_p_ders__distract_001

    • mh_p_ders__distract_002

    • mh_p_ders__distract_003

    • mh_p_ders__distract_004

  • Excluded values:

    • 999

    • 777

Usage

compute_mh_p_ders__distract_nm(
  data,
  name = "mh_p_ders__distract_nm",
  exclude = c("999", "777"),
  combine = TRUE
)

Value

tbl. see combine.

Arguments

data

tbl. Data frame containing the columns to be summarized.

name

character. Name of the summary score column.

exclude

character vector. Values to be excluded from the summary score calculation.

combine

logical. If TRUE (default), the summary score is is appended as a new column to the input data frame. If FALSE, the summary score is returned as a separate one-column data frame.

See Also

compute_mh_p_ders__distract_mean()

Examples

Run this code
if (FALSE) {
compute_mh_p_ders__distract_nm(data) |>
  select(
    any_of(c("mh_p_ders__distract_nm", vars_mh_p_ders__distract))
  )
}

Run the code above in your browser using DataLab