powered by
Computes the summary score mh_p_eatq__surg_nm Early Adolescent Temperament Questionnaire [Parent] (Surgency): Number missing
mh_p_eatq__surg_nm
Summarized variables:
mh_p_eatq__surg_001
mh_p_eatq__surg_002
mh_p_eatq__surg_003
mh_p_eatq__surg_004
mh_p_eatq__surg_005
mh_p_eatq__surg_006
mh_p_eatq__surg_007
mh_p_eatq__surg_008
mh_p_eatq__surg_009
Excluded values: none
compute_mh_p_eatq__surg_nm(data, name = "mh_p_eatq__surg_nm", combine = TRUE)
tbl. The input data frame with the summary score appended as a new column.
tbl, Dataframe containing the columns to be summarized.
character, Name of the new column to be created. Default is the name in description, but users can change it.
logical, If TRUE, the summary score will be appended to the input data frame. If FALSE, the summary score will be returned as a separate data frame.
TRUE
FALSE
compute_mh_p_eatq__surg_mean()
if (FALSE) { data <- compute_mh_p_eatq__surg_nm(data) select( data, any_of(c("mh_p_eatq__surg_nm", vars_mh_p_eatq__surg)) ) }
Run the code above in your browser using DataLab