Learn R Programming

ABCDscores (version 6.1.0)

compute_mh_p_ple_all: Compute all summary scores for mh_p_ple

Description

This function computes all summary scores for the mh_p_ple form. Make sure to have all necessary columns in the data frame.

Usage

compute_mh_p_ple_all(data)

Value

tbl. The input data frame with the summary scores appended as new columns.

Arguments

data

tbl. Data frame containing the columns to be summarized.

Examples

Run this code
if (FALSE) {
compute_mh_p_ple_all(data)
}

Run the code above in your browser using DataLab