Learn R Programming

ABCDscores (version 6.1.0)

compute_mh_y_erq__reapp_nm: Compute "Emotion Regulation Questionnaire [Youth] (Reappraisal): Number missing"

Description

Computes the summary score mh_y_erq__reapp_nm Emotion Regulation Questionnaire [Youth] (Reappraisal): Number missing

  • Summarized variables:

    • mh_y_erq__reapp_001

    • mh_y_erq__reapp_002

    • mh_y_erq__reapp_003

  • Excluded values:

    • 777

Usage

compute_mh_y_erq__reapp_nm(
  data,
  name = "mh_y_erq__reapp_nm",
  exclude = c("777"),
  combine = TRUE
)

Value

tbl. see combine.

Arguments

data

tbl. Data frame containing the columns to be summarized.

name

character. Name of the summary score column.

exclude

character vector. Values to be excluded from the summary score calculation.

combine

logical. If TRUE (default), the summary score is is appended as a new column to the input data frame. If FALSE, the summary score is returned as a separate one-column data frame.

See Also

compute_mh_y_erq__reapp_mean()

Examples

Run this code
if (FALSE) {
compute_mh_y_erq__reapp_nm(data) |>
  select(
    any_of(c("mh_y_erq__reapp_nm", vars_mh_y_erq__reapp))
  )
}

Run the code above in your browser using DataLab