powered by
Computes the summary score mh_y_pps_nm Prodromal Psychosis Scale [Youth] (number of responses): Number missing
mh_y_pps_nm
Summarized variables:
mh_y_pps_001
mh_y_pps_002
mh_y_pps_003
mh_y_pps_004
mh_y_pps_005
mh_y_pps_006
mh_y_pps_007
mh_y_pps_008
mh_y_pps_009
mh_y_pps_010
mh_y_pps_011
mh_y_pps_012
mh_y_pps_013
mh_y_pps_014
mh_y_pps_015
mh_y_pps_016
mh_y_pps_017
mh_y_pps_018
mh_y_pps_019
mh_y_pps_020
mh_y_pps_021
compute_mh_y_pps_nm(data, name = "mh_y_pps_nm", combine = TRUE)
tbl. The input data frame with the summary score appended as a new column.
tbl, Dataframe containing the columns to be summarized.
character, Name of the new column to be created. Default is the name in description, but users can change it.
logical, If TRUE, the summary score will be appended to the input data frame. If FALSE, the summary score will be returned as a separate data frame.
TRUE
FALSE
compute_mh_y_pps_count()
if (FALSE) { compute_mh_y_pps_nm(data) |> select( any_of(c("mh_y_pps_nm", vars_mh_y_pps_count)) ) }
Run the code above in your browser using DataLab