Learn R Programming

ABCDscores (version 6.1.0)

compute_nc_y_ehis_nm: Compute "Edinburgh Handedness Inventory [Youth]: Number missing"

Description

Computes the summary score nc_y_ehis_nm Edinburgh Handedness Inventory [Youth]: Number missing

  • Summarized variables:

    • nc_y_ehis_001

    • nc_y_ehis_002

    • nc_y_ehis_003

    • nc_y_ehis_004

Usage

compute_nc_y_ehis_nm(data, name = "nc_y_ehis_nm", combine = TRUE)

Value

tbl. The input data frame with the summary score appended as a new column.

Arguments

data

tbl, Dataframe containing the columns to be summarized.

name

character, Name of the new column to be created. Default is the name in description, but users can change it.

combine

logical, If TRUE, the summary score will be appended to the input data frame. If FALSE, the summary score will be returned as a separate data frame.

See Also

compute_nc_y_ehis_score()

Examples

Run this code
if (FALSE) {
compute_nc_y_ehis_nm(data) |>
  select(
    data,
    all_of(c("nc_y_ehis_nm", vars_nc_y_ehis))
  )
}

Run the code above in your browser using DataLab