Learn R Programming

ABCDscores (version 6.1.0)

compute_nt_y_stq_all: Compute all summary scores for nt_y_stq

Description

This function computes all summary scores for the nt_y_stq form. Make sure to have all necessary columns in the data frame.

Usage

compute_nt_y_stq_all(data)

Value

tbl. The input data frame with the summary scores appended as new columns.

Arguments

data

tbl. Data frame containing the columns to be summarized.

Examples

Run this code
if (FALSE) {
compute_nt_y_stq_all(data)
}

Run the code above in your browser using DataLab