powered by
Computes the summary score ph_p_cna_sum Child Nutrition Assessment [Parent]: Sum [Validation: No more than 0 missing or declined]
ph_p_cna_sum
Summarized variables:
ph_p_cna_001
ph_p_cna_002
ph_p_cna_003
ph_p_cna_004
ph_p_cna_005
ph_p_cna_006
ph_p_cna_007
ph_p_cna_008
ph_p_cna_009
ph_p_cna_010
ph_p_cna_011
ph_p_cna_012
ph_p_cna_013
ph_p_cna_014
Excluded values:
999
777
compute_ph_p_cna_nm( data, name = "ph_p_cna_nm", exclude = c("777", "999"), combine = TRUE )
tbl. The input data frame with the summary score appended as a new column.
tbl, Dataframe containing the columns to be summarized.
character, Name of the new column to be created. Default is the name in description, but users can change it.
character, Values to be excluded from the summary score.
logical, If TRUE, the summary score will be appended to the input data frame. If FALSE, the summary score will be returned as a separate data frame.
TRUE
FALSE
if (FALSE) { compute_ph_p_cna_nm(data) |> select( all_of(c("ph_p_cna_nm", vars_ph_p_cna)) ) }
Run the code above in your browser using DataLab