powered by
A single function to compute all scores in the above domain using default arguments.
compute_ph_p_otbi_all(data)
tbl. The input data frame with the summary scores appended as new columns.
tbl. Dataframe containing the columns to be summarized.
if (FALSE) { compute_ph_p_otbi_all(data) }
Run the code above in your browser using DataLab