Computes the summary score ph_p_sds__da_nm
Sleep Disturbance Scale [Parent] (Disorder of arousal) - Number missing
Summarized variables:
ph_p_sds__da_001
ph_p_sds__da_002
ph_p_sds__da_003
Excluded values:
777
999
compute_ph_p_sds__da_nm(
data,
name = "ph_p_sds__da_nm",
exclude = c("777", "999"),
combine = TRUE
)tbl. The input data frame with the summary score appended as a new column.
tbl, Dataframe containing the columns to be summarized.
character, Name of the new column to be created. Default is the name in description, but users can change it.
character, Values to be excluded from the summary score.
logical, If TRUE, the summary score will be appended to
the input data frame. If FALSE, the summary score will be returned as a
separate data frame.
compute_ph_p_sds__da_sum()