powered by
Computes the summary score ph_y_anthr__height_nm Anthropometrics [Youth] (Height): Number missing
ph_y_anthr__height_nm
Summarized variables:
ph_y_anthr__height__r01_001
ph_y_anthr__height__r02_001
ph_y_anthr__height__r03_001
Excluded values: none
compute_ph_y_anthr__height_nm( data, name = "ph_y_anthr__height_nm", combine = TRUE )
tbl. The input data frame with the summary score appended as a new column.
tbl, Dataframe containing the columns to be summarized.
character, Name of the new column to be created. Default is the name in description, but users can change it.
logical, If TRUE, the summary score will be appended to the input data frame. If FALSE, the summary score will be returned as a separate data frame.
TRUE
FALSE
compute_ph_y_anthr__height_mean()
if (FALSE) { compute_ph_y_anthr__height_nm(data) |> select( all_of(c("ph_y_anthr__height_nm", vars_ph_y_anthr__height)) ) }
Run the code above in your browser using DataLab