powered by
Computes the summary score ph_y_mctq__fd_count Munich Chronotype Questionnaire [Youth] (Free Day): Count
ph_y_mctq__fd_count
Summarized variables:
ph_y_mctq__sd_count (intermediate score)
ph_y_mctq__sd_count
Excluded values: none
compute_ph_y_mctq__fd_count(data, name = "ph_y_mctq__fd_count", combine = TRUE)
tbl. The input data frame with the summary score appended as a new column.
tbl. Data frame containing the columns to be summarized.
character. Name of the new column to be created (Default: the name used in the ABCD data release).
logical. If TRUE, the new column will be bound to the input data frame. If FALSE, the new column will be created as a new data frame.
if (FALSE) { compute_ph_y_mctq__fd_count(data) |> select( any_of(c( "ph_y_mctq__fd_count" )) ) }
Run the code above in your browser using DataLab