powered by
Computes the summary score ph_y_mctq__socjl_rel Munich Chronotype Questionnaire [Youth] (Social Jetlag: Relative): Time
ph_y_mctq__socjl_rel
Summarized variables:
ph_y_mctq__fd__sleep__mid__36h_t (intermediate score)
ph_y_mctq__fd__sleep__mid__36h_t
ph_y_mctq__sd__sleep__mid__36h_t (intermediate score)
ph_y_mctq__sd__sleep__mid__36h_t
Excluded values: none
compute_ph_y_mctq__socjl_rel( data, name = "ph_y_mctq__socjl_rel", combine = TRUE )
tbl. The input data frame with the summary score appended as a new column.
tbl. Data frame containing the columns to be summarized.
character. Name of the new column to be created (Default: the name used in the ABCD data release).
logical. If TRUE, the new column will be bound to the input data frame. If FALSE, the new column will be created as a new data frame.
if (FALSE) { compute_ph_y_mctq__socjl_rel(data) |> select( any_of(c( "ph_y_mctq__socjl_rel" )) ) }
Run the code above in your browser using DataLab