Learn R Programming

ABCDscores (version 6.1.0)

compute_ph_y_mctq_all: Compute all the MCTQ variables

Description

Compute all the MCTQ variables

Usage

compute_ph_y_mctq_all(data)

Value

tbl. The input data frame with the summary scores appended as new columns.

Arguments

data

tbl, Dataframe containing the columns to be summarized.

Details

Make sure the data is the full set of all variables from MCTQ.

Examples

Run this code
if (FALSE) {
compute_ph_y_mctq_all(data)
}

Run the code above in your browser using DataLab