Learn R Programming

ABCDscores (version 6.1.0)

compute_ph_y_mctq_chrono: Compute "Munich Chronotype Questionnaire [Youth] (Chronotype): Time"

Description

Computes the summary score ph_y_mctq_chrono Munich Chronotype Questionnaire [Youth] (Chronotype): Time

  • Summarized variables:

    • ph_y_mctq__fd_007

    • ph_y_mctq__fd__sleep_period (intermediate score)

    • ph_y_mctq__sd__sleep_period (intermediate score)

    • ph_y_mctq__fd__sleep__mid__36h_t (intermediate score)

    • ph_y_mctq__fd__sleep__onset__36h_t (intermediate score)

    • ph_y_mctq__sleep_period (intermediate score)

  • Excluded values: none

Usage

compute_ph_y_mctq_chrono(data, name = "ph_y_mctq_chrono", combine = TRUE)

Value

tbl. The input data frame with the summary score appended as a new column.

Arguments

data

tbl. Data frame containing the columns to be summarized.

name

character. Name of the new column to be created (Default: the name used in the ABCD data release).

combine

logical. If TRUE, the new column will be bound to the input data frame. If FALSE, the new column will be created as a new data frame.

Examples

Run this code
if (FALSE) {
compute_ph_y_mctq_chrono(data) |>
  select(
    any_of(c(
      "ph_y_mctq_chrono"
    ))
  )
}

Run the code above in your browser using DataLab