Computes the summary score ph_y_pds__m_nm
Pubertal Development Scale & Menstrual Cycle Survey History [Youth]
(Male): Number missing
Summarized variables:
ph_y_pds_001
ph_y_pds_002
ph_y_pds_003
ph_y_pds__m_001
ph_y_pds__m_002
Excluded values:
777
999
compute_ph_y_pds__m_nm(
data,
name = "ph_y_pds__m_nm",
exclude = c("777", "999"),
combine = TRUE
)tbl. The input data frame with the summary score appended as a new column.
tbl. Data frame containing the columns to be summarized.
character. Name of the summary score column.
character vector. Values to be excluded from the summary score calculation.
logical. If TRUE (default), the summary score is
is appended as a new column to the input data frame. If FALSE, the
summary score is returned as a separate one-column data frame.
compute_ph_y_pds__m_mean()