Learn R Programming

ABCDscores (version 6.1.0)

compute_su_y_alchss_all: Compute all Alcohol Hangover Symptoms Scale (HSS) Youth summary scores

Description

compute all summary scores of Alcohol Hangover Symptoms Scale (HSS) Youth

Usage

compute_su_y_alchss_all(data)

Value

tbl. The input data frame with the summary score appended as a new column.

Arguments

data

tbl, Dataframe containing the columns to be summarized.

Examples

Run this code
if (FALSE) {
compute_su_y_alchss_all(data)
}

Run the code above in your browser using DataLab