Computes the summary score su_y_alchss_count
Alcohol Hangover Symptoms Scale (HSS) [Youth]: Count
Summarized variables:
su_y_alchss_001
su_y_alchss_002
su_y_alchss_003
su_y_alchss_004
su_y_alchss_005
su_y_alchss_006
su_y_alchss_007
su_y_alchss_008
su_y_alchss_009
su_y_alchss_010
su_y_alchss_011
su_y_alchss_012
su_y_alchss_013
su_y_alchss_014
su_y_alchss_001__l
su_y_alchss_002__l
su_y_alchss_003__l
su_y_alchss_004__l
su_y_alchss_005__l
su_y_alchss_006__l
su_y_alchss_007__l
su_y_alchss_008__l
su_y_alchss_009__l
su_y_alchss_010__l
su_y_alchss_011__l
su_y_alchss_012__l
su_y_alchss_013__l
su_y_alchss_014__l
Excluded values: none
Validation criterion: maximally 0 of 2 items missing
compute_su_y_alchss_count(
data,
name = "su_y_alchss_count",
max_na = 0,
combine = TRUE
)tbl. The input data frame with the summary score appended as a new column.
tbl, Dataframe containing the columns to be summarized.
character, Name of the new column to be created. Default is the name in description, but users can change it.
integer, Maximum number of missing values allowed in the summary score.
logical, If TRUE, the summary score will be appended to
the input data frame. If FALSE, the summary score will be returned as a
separate data frame.
compute_su_y_alchss_sum()
if (FALSE) {
compute_su_y_alchss_count(data) |> View()
}
Run the code above in your browser using DataLab