Computes the summary score su_y_alcsre__6mo_count
Alcohol Subject Response and Effects [Youth] (Last 6 months): Count
[Validation: None missing or declined]
Summarized variables:
su_y_alcsre__6mo_001
su_y_alcsre__6mo_002
su_y_alcsre__6mo_003
su_y_alcsre__6mo_004
Excluded values: none
Validation criterion: maximally 0 of 4 items missing
compute_su_y_alcsre__6mo_count(
data,
name = "su_y_alcsre__6mo_count",
combine = TRUE,
max_na = 0
)tbl. The input data frame with the summary score appended as a new column.
tbl. Data frame containing the columns to be summarized.
character. Name of the new column to be created (Default: the name used in the ABCD data release).
logical. If TRUE, the new column will be bound to the input data frame. If FALSE, the new column will be created as a new data frame.
numeric, positive whole number. Number of missing items allowed (Default: 0).