Computes the summary score su_y_alcsre__6mo_nm
Alcohol Subject Response and Effects [Youth] (Last 6 months): Number
missing
Summarized variables:
su_y_alcsre__6mo_001
su_y_alcsre__6mo_002
su_y_alcsre__6mo_003
su_y_alcsre__6mo_004
Excluded values: none
compute_su_y_alcsre__6mo_nm(data, name = "su_y_alcsre__6mo_nm", combine = TRUE)tbl. The input data frame with the summary score appended as a new column.
tbl. Data frame containing the columns to be summarized.
character. Name of the new column to be created (Default: the name used in the ABCD data release).
logical. If TRUE, the new column will be bound to the input data frame. If FALSE, the new column will be created as a new data frame.