Computes the summary score su_y_mjexp__neg_nm
Marijuana Expectancies (MEEQ-B) [Youth] (Strength of negative
expectancies): Number missing
Summarized variables:
su_y_mjexp__neg_001
su_y_mjexp__neg_002
su_y_mjexp__neg_003
Excluded values: none
compute_su_y_mjexp__neg_nm(data, name = "su_y_mjexp__neg_nm", combine = TRUE)tbl. The input data frame with the summary score appended as a new column.
tbl. Data frame containing the columns to be summarized.
character, Name of the new column to be created. Default is the name in description, but users can change it.
logical, If TRUE (default), the summary score will be appended to
the input data frame. If FALSE, the summary score for each participant
will be returned as a separate data frame. (Default: TRUE)
compute_su_y_mjexp__neg_prsum()