powered by
This function computes all summary scores for the su_y_mjsre form. Make sure to have all necessary columns in the data frame.
compute_su_y_mjsre_all(data)
tbl. The input data frame with the summary scores appended as new columns.
tbl. Data frame containing the columns to be summarized.
if (FALSE) { compute_su_y_mjsre_all(data) }
Run the code above in your browser using DataLab