Computes the summary score su_y_mjsre_nm
Marijuana Subjective Response and Effects [Youth] (NA): Number missing
Summarized variables:
su_y_mjsre__pos_001
su_y_mjsre__pos_002
su_y_mjsre__pos_003
su_y_mjsre__neg_001
su_y_mjsre__neg_002
su_y_mjsre__neg_003
su_y_mjsre__neg_004
su_y_mjsre__neg_005
su_y_mjsre__neg_006
su_y_mjsre__neg_007
su_y_mjsre__neg_008
Excluded values: none
compute_su_y_mjsre_nm(data, name = "su_y_mjsre_nm", combine = TRUE)tbl. The input data frame with the summary score appended as a new column.
tbl. Data frame containing the columns to be summarized.
character. Name of the new column to be created (Default: the name used in the ABCD data release).
logical. If TRUE, the new column will be bound to the input data frame. If FALSE, the new column will be created as a new data frame.