Dummy function for all MH summary score functions.
dummy_mh(data, name, max_na, combine, exclude, event, events)tbl. see combine.
tbl. Data frame containing the columns to be summarized.
character. Name of the summary score column.
numeric, positive whole number. Number of missing items
allowed. NULL means no limit.
logical. If TRUE (default), the summary score is
is appended as a new column to the input data frame. If FALSE, the
summary score is returned as a separate one-column data frame.
character vector. Values to be excluded from the summary score calculation.
character. Event (session ID) to be used.
character vector. Event (session ID) to be used.