Dummy function for all OBTI score functions.
dummy_ph_p_otbi(data, name, combine, max_na, exclude)tbl. see combine.
tbl. Data frame containing the columns to be summarized.
character. Name of the summary score column.
logical. If TRUE (default), the summary score is
is appended as a new column to the input data frame. If FALSE, the
summary score is returned as a separate one-column data frame.
numeric, positive whole number. Number of missing items
allowed. NULL means no limit.
character vector. Values to be excluded from the summary score calculation.