powered by
Creates a bullet point list in markdown format. Copy of gluedown::md_bullet() but with the added ability to specify an indent to create nested lists and the option to use code font.
gluedown::md_bullet()
md_bullet( x, indent = 0, code = FALSE, italic = FALSE, marker = c("*", "-", "+") )
glue vector. A bullet point list in markdown format.
glue
character (vector). Text to convert into a bullet point list.
numeric, positive whole number. Number of spaces to indent the bullet point list by (Default: 0).
logical. If the text will be formatted as code (Default: TRUE).
logical. If the text will be formatted as italic (Default: FALSE).
character. The bullet list marker to use (Default: "*").
md_bullet(c("First item", "Second item", "Third item"), code = TRUE) md_bullet(c("First item", "Second item", "Third item"), indent = 2)
Run the code above in your browser using DataLab