Computes the summary score fc_p_fes__cohes_mean
(Family Environment Scale [Parent] (Cohesion): Mean)
Summarized variables:
fc_p_fes__cohes_001
fc_p_fes__cohes_002
fc_p_fes__cohes_003
fc_p_fes__cohes_004
fc_p_fes__cohes_005
fc_p_fes__cohes_006
fc_p_fes__cohes_007
fc_p_fes__cohes_008
fc_p_fes__cohes_009
Excluded values: none
Validation criterion: maximally 1 of 9 items missing
vars_fc_p_fes__cohescompute_fc_p_fes__cohes_mean(
data,
name = "fc_p_fes__cohes_mean",
max_na = 1,
combine = TRUE
)
tbl. The input data frame with the summary score appended as a new column.
vars_fc_p_fes__cohes is a character vector of all column names
used to compute summary score of fc_p_fes__cohes.
tbl. Data frame containing the columns to be summarized.
character. Name of the summary score. Default is the name in the description.
numeric, positive whole number. Number of missing items allowed (Default: 1).
logical. If TRUE, the summary score is appended to the input
data frame. If FALSE, the summary score is returned as a separate data
frame. Default is TRUE.