Computes the summary score fc_p_vs__indselfrel_mean
(Values Scale [Parent] (Independence and
self-reliance): Mean)
Summarized variables:
fc_p_vs__indselfrel_001
fc_p_vs__indselfrel_002
fc_p_vs__indselfrel_003
fc_p_vs__indselfrel_004
fc_p_vs__indselfrel_005
Excluded values: none
Validation criterion: maximally 1 of 5 items missing
vars_fc_p_vs__indselfrelcompute_fc_p_vs__indselfrel_mean(
data,
name = "fc_p_vs__indselfrel_mean",
max_na = 1,
combine = TRUE
)
tbl. The input data frame with the summary score appended as a new column.
vars_fc_p_vs__indselfrel is a character vector of all column names
used to compute summary score of fc_p_vs__indselfrel.
tbl. Data frame containing the columns to be summarized.
character. Name of the summary score. Default is the name in the description.
numeric, positive whole number. Number of missing items allowed (Default: 1).
logical. If TRUE, the summary score is appended to the
input data frame. If FALSE, the summary score is returned as a separate
data frame. Default is TRUE.