Computes the summary score fc_y_srpf__dis_mean
(School Risk & Protective Factors [Youth] (School disengagement): Mean)
Summarized variables:
fc_y_srpf__dis_001
fc_y_srpf__dis_002
Excluded values: none
Validation criterion: none of 2 items missing
vars_fc_y_srpf__discompute_fc_y_srpf__dis_mean(
data,
name = "fc_y_srpf__dis_mean",
max_na = 0,
combine = TRUE
)
tbl. The input data frame with the summary score appended as a new column.
vars_fc_y_srpf__dis is a character vector of all column names
used to compute summary score of fc_y_srpf__dis.
tbl. Data frame containing the columns to be summarized.
character. Name of the summary score. Default is the name in the description.
numeric, positive whole number. Number of missing items allowed (Default: 0).
logical. If TRUE, the summary score is appended to the
input data frame. If FALSE, the summary score is returned as a separate
data frame. Default is TRUE.