Learn R Programming

ABCDscores (version 6.1.0)

vars_mh_p_abcl__cg2: Compute "Adult Behavior Checklist [Parent] Sex Assignment"

Description

Computes the summary score mh_p_abcl__cg2_sex Adult Behavior Checklist [Parent] Sex Assignment

  • Summarized variables:

    • mh_p_abcl__cg2_001

  • Excluded values:

    • 777

    • 999

Usage

vars_mh_p_abcl__cg2

compute_mh_p_abcl__cg2_sex(data, name = "mh_p_abcl__cg2_sex", combine = TRUE)

Value

tbl. see combine.

Format

vars_mh_p_abcl__cg2 is vector of all column names used to compute summary score of mh_p_abcl__cg2 scores.

Arguments

data

tbl. Data frame containing the columns to be summarized.

name

character. Name of the summary score column.

combine

logical. If TRUE (default), the summary score is is appended as a new column to the input data frame. If FALSE, the summary score is returned as a separate one-column data frame.

Examples

Run this code
if (FALSE) {
compute_mh_p_abcl__cg2_sex(data) |>
  select(
    any_of(c("mh_p_abcl__cg2_sex", vars_mh_p_abcl__cg2))
  )
}

Run the code above in your browser using DataLab