Learn R Programming

ABCDscores (version 6.1.0)

vars_mh_p_abcl__dsm__avoid: Compute "Adult Behavior Checklist [Parent] (DSM-5 Oriented Scale - Avoidant personality problems): Number missing"

Description

Computes the summary score mh_p_abcl__dsm__avoid_nm Adult Behavior Checklist [Parent] (DSM-5 Oriented Scale - Avoidant personality problems): Number missing

  • Summarized variables:

    • mh_p_abcl__anxdep__avoid_001

    • mh_p_abcl__anxdep__avoid_002

    • mh_p_abcl__othpr__avoid_001

    • mh_p_abcl__wthdr__avoid_001

    • mh_p_abcl__wthdr__avoid_002

    • mh_p_abcl__wthdr__avoid_003

    • mh_p_abcl__wthdr__avoid_004

  • Excluded values:

    • 777

    • 999

Usage

vars_mh_p_abcl__dsm__avoid

compute_mh_p_abcl__dsm__avoid_nm( data, name = "mh_p_abcl__dsm__avoid_nm", exclude = c("777", "999"), combine = TRUE )

Value

tbl. see combine.

Format

vars_mh_p_abcl__dsm__avoid is vector of all column names used to compute summary score of mh_p_abcl__dsm__avoid scores.

Arguments

data

tbl. Data frame containing the columns to be summarized.

name

character. Name of the summary score column.

exclude

character vector. Values to be excluded from the summary score.

combine

logical. If TRUE (default), the summary score is is appended as a new column to the input data frame. If FALSE, the summary score is returned as a separate one-column data frame.

Examples

Run this code
if (FALSE) {
compute_mh_p_abcl__dsm__avoid_nm(data) |>
  select(
    any_of(c("mh_p_abcl__dsm__avoid_nm", vars_mh_p_abcl__dsm__avoid))
  )
}

Run the code above in your browser using DataLab