powered by
Computes the summary score mh_p_eatq__affl_mean Early Adolescent Temperament Questionnaire [Parent] (Affiliation): Mean
mh_p_eatq__affl_mean
Summarized variables:
mh_p_eatq__affl_001
mh_p_eatq__affl_002
mh_p_eatq__affl_003
mh_p_eatq__affl_004
mh_p_eatq__affl_005
mh_p_eatq__affl_006
Excluded values: none
Validation criterion: maximally 1 of 6 items missing
vars_mh_p_eatq__afflcompute_mh_p_eatq__affl_mean( data, name = "mh_p_eatq__affl_mean", max_na = 1, combine = TRUE, revert = FALSE )
compute_mh_p_eatq__affl_mean( data, name = "mh_p_eatq__affl_mean", max_na = 1, combine = TRUE, revert = FALSE )
tbl. The input data frame with the summary score appended as a new column.
vars_mh_p_eatq__affl is a character vector of all column names used to compute summary score of mh_p_eatq__affl_mean.
tbl, Dataframe containing the columns to be summarized.
character, Name of the new column to be created. Default is the name in description, but users can change it.
integer, Maximum number of missing values allowed in the summary score. NULL means no limit.
NULL
logical, If TRUE, the summary score will be appended to the input data frame. If FALSE, the summary score will be returned as a separate data frame.
TRUE
FALSE
logical, If TRUE, the summary score will be reverse scored.
if (FALSE) { data <- compute_mh_p_eatq__affl_mean(data) select( data, any_of(c("mh_p_eatq__affl_mean", vars_mh_p_eatq__affl)) ) }
Run the code above in your browser using DataLab