Computes the summary score mh_p_ple_count
Life Events [Parent] (Events): Count [Validation: No more than 5
missing or declined]
Summarized variables:
mh_p_ple_001
mh_p_ple_002
mh_p_ple_003
mh_p_ple_004
mh_p_ple_005
mh_p_ple_006
mh_p_ple_007
mh_p_ple_008
mh_p_ple_009
mh_p_ple_010
mh_p_ple_011
mh_p_ple_012
mh_p_ple_013
mh_p_ple_014
mh_p_ple_015
mh_p_ple_016
mh_p_ple_017
mh_p_ple_018
mh_p_ple_019
mh_p_ple_020
mh_p_ple_021
mh_p_ple_022
mh_p_ple_023
mh_p_ple_024
mh_p_ple_025
Excluded values:
444
777
999
Validation criterion: maximally 5 of 25 items missing
vars_mh_p_plevars_mh_p_ple__exp
compute_mh_p_ple_count(
data,
name = "mh_p_ple_count",
combine = TRUE,
max_na = 5
)
tbl. The input data frame with the summary score appended as a new column.
vars_mh_p_ple is a character vector of all column names
used to compute summary score of mh_p_ple.
vars_mh_p_ple__exp is a character vector of all column names
used to compute summary score of mh_p_ple__exp.
tbl. Data frame containing the columns to be summarized.
character. Name of the new column to be created (Default: the name used in the ABCD data release).
logical. If TRUE, the new column will be bound to the input data frame. If FALSE, the new column will be created as a new data frame.
numeric, positive whole number. Number of missing items allowed (Default: 5).