powered by
Computes the summary score ph_y_bp__sys_mean Blood Pressure [Youth] (Systolic): Mean
ph_y_bp__sys_mean
Summarized variables:
ph_y_bp__sys__r01_001
ph_y_bp__sys__r01_002
ph_y_bp__sys__r01_003
ph_y_bp__sys__r02_001
ph_y_bp__sys__r02_002
ph_y_bp__sys__r03_001
ph_y_bp__sys__r03_002
Excluded values: none
vars_ph_y_bp__syscompute_ph_y_bp__sys_mean(data, name = "ph_y_bp__sys_mean", combine = TRUE)
compute_ph_y_bp__sys_mean(data, name = "ph_y_bp__sys_mean", combine = TRUE)
tbl. The input data frame with the summary score appended as a new column.
vars_ph_y_bp__sys is a character vector of all column names used to compute summary scores of ph_y_bp__sys.
ph_y_bp__sys
tbl, Dataframe containing the columns to be summarized.
character, Name of the new column to be created. Default is the name in description, but users can change it.
logical, If TRUE, the summary score will be appended to the input data frame. If FALSE, the summary score will be returned as a separate data frame.
TRUE
FALSE
if (FALSE) { compute_ph_y_bp__sys_mean(data) |> select( all_of(c("ph_y_bp__sys_mean", vars_ph_y_bp__sys)) ) }
Run the code above in your browser using DataLab