Computes the summary score ph_y_pds__f_mean
Pubertal Development Scale & Menstrual Cycle Survey History [Youth]
(Female): Mean [Validation: No more than 1 missing or declined]
Summarized variables:
ph_y_pds_001
ph_y_pds_002
ph_y_pds_003
ph_y_pds__f_001
ph_y_pds__f_002
Excluded values:
777
999
Validation criterion: maximally 1 item missing
vars_ph_y_pds__fcompute_ph_y_pds__f_mean(
data,
name = "ph_y_pds__f_mean",
exclude = c("777", "999"),
combine = TRUE,
max_na = 1
)
tbl. The input data frame with the summary score appended as a new column.
vars_ph_y_pds__f is a character vector of all column names
used to compute summary score of ph_y_pds__f_mean and
ph_y_pds__f_nm.
tbl. Data frame containing the columns to be summarized.
character. Name of the summary score column.
character vector. Values to be excluded from the summary score calculation.
logical. If TRUE (default), the summary score is
is appended as a new column to the input data frame. If FALSE, the
summary score is returned as a separate one-column data frame.
numeric, positive whole number. Number of missing items
allowed. NULL means no limit.