Computes the summary score ph_y_pds__m_categ
Pubertal Development Scale & Menstrual Cycle Survey History [Youth]
(Male): Approximate tanner stages [Validation: No more than 0
missing or declined]
Summarized variables:
ph_y_pds_002
ph_y_pds__m_001
ph_y_pds__m_002
Excluded values:
777
999
Validation criterion: maximally 0 items missing
vars_ph_y_pds__m_categcompute_ph_y_pds__m_categ(
data,
name = "ph_y_pds__m_categ",
combine = TRUE,
exclude = c("777", "999"),
max_na = 0
)
tbl. The input data frame with the summary score appended as a new column.
vars_ph_y_pds__m is a character vector of all column names
used to compute summary score of ph_y_pds__m_categ and
ph_y_pds__m__categ_nm.
tbl. Data frame containing the columns to be summarized.
character. Name of the summary score column.
logical. If TRUE (default), the summary score is
is appended as a new column to the input data frame. If FALSE, the
summary score is returned as a separate one-column data frame.
character vector. Values to be excluded from the summary score calculation.
numeric, positive whole number. Number of missing items
allowed. NULL means no limit.