Computes the summary score su_y_caff__espres_sum
Caffeine Use Questionnaire [Youth] (Espresso): Sum [Validation: None]
Summarized variables:
su_y_caff__espres_001
su_y_caff__espres_001__01
su_y_caff__espres_001__02
su_y_caff__espres_001__l
Excluded values: none
Validation criterion: none
vars_su_y_caff__esprescompute_su_y_caff__espres_sum(
data,
name = "su_y_caff__espres_sum",
combine = TRUE
)
tbl. The input data frame with the summary score appended as a new column.
vars_su_y_caff__espres is a character vector of all column names used
to compute compute_su_y_caff__espres_sum.
tbl. Data frame containing the columns to be summarized.
character. Name of the new column to be created (Default: the name used in the ABCD data release).
logical. If TRUE, the new column will be bound to the input data frame. If FALSE, the new column will be created as a new data frame.