Computes the summary score su_y_mjexp__neg_prsum
Marijuana Expectancies (MEEQ-B) [Youth] (Strength of negative
expectancies): Prorated sum [Validation: No more than 1
missing or declined]
Summarized variables:
su_y_mjexp__neg_001
su_y_mjexp__neg_002
su_y_mjexp__neg_003
Excluded values: none
Validation criterion: maximally 1 of 3 items missing
vars_su_y_mjexp__negcompute_su_y_mjexp__neg_prsum(
data,
name = "su_y_mjexp__neg_prsum",
combine = TRUE,
max_na = 1
)
tbl. The input data frame with the summary score appended as a new column.
vars_su_y_mjexp__neg is a character vector of all column names
used to compute summary score of su_y_mjexp__neg_prsum and
su_y_mjexp__neg_nm.
tbl. Data frame containing the columns to be summarized.
character, Name of the new column to be created. Default is the name in description, but users can change it.
logical, If TRUE (default), the summary score will be appended to
the input data frame. If FALSE, the summary score for each participant
will be returned as a separate data frame. (Default: TRUE)
numeric, positive whole number. Number of missing items allowed (Default: 1).