Provides functions to compute summary scores (besides proprietary ones) reported in the tabulated data resource that is released by the Adolescent Brain Cognitive Development (ABCD) study.
Maintainer: Le Zhang dairc.service@gmail.com (ORCID)
Authors:
Janosch Linkersdoerfer linkersdoerfer@gmail.com (ORCID)
Olivier Celhay olivier.celhay@gmail.com (ORCID)
Biplabendu Das biplabendu.das@gmail.com (ORCID)
Sammy Berman sammyberman@gmail.com (ORCID)
Laura Ziemer lrziemer@gmail.com (ORCID)
Zhang, L., Celhay, O., Das, B., Berman, S., Ziemer, L. R., Smith, C. J., Dale, A. M., & Linkersdörfer, J. (2025). ABCDscores: An R package for computing summary scores in the ABCD Study. bioRxiv. tools:::Rd_expr_doi("10.1101/2025.09.04.674066")
Useful links: