powered by
This is a high-level function that computes all summary scores in this table. Make sure the data contains all the necessary columns.
data
compute_fc_p_vs_all(data)
tbl. The input data frame with the summary scores appended as new columns.
tbl, Dataframe containing the columns to be summarized.
if (FALSE) { compute_fc_p_vs_all(data) }
Run the code above in your browser using DataLab