powered by
This function computes all summary scores for the mh_p_ple form. Make sure to have all necessary columns in the data frame.
compute_mh_p_ple_all(data)
tbl. The input data frame with the summary scores appended as new columns.
tbl. Data frame containing the columns to be summarized.
if (FALSE) { compute_mh_p_ple_all(data) }
Run the code above in your browser using DataLab