powered by
This function computes all summary scores for the nt_y_stq form. Make sure to have all necessary columns in the data frame.
compute_nt_y_stq_all(data)
tbl. The input data frame with the summary scores appended as new columns.
tbl. Data frame containing the columns to be summarized.
if (FALSE) { compute_nt_y_stq_all(data) }
Run the code above in your browser using DataLab