powered by
Compute all the MCTQ variables
compute_ph_y_mctq_all(data)
tbl. The input data frame with the summary scores appended as new columns.
tbl, Dataframe containing the columns to be summarized.
Make sure the data is the full set of all variables from MCTQ.
data
if (FALSE) { compute_ph_y_mctq_all(data) }
Run the code above in your browser using DataLab