compute_su_y_caff_all: Compute all the SU youth caff scores
Description
A single function to compute all caff scores in SU domain.
Usage
compute_su_y_caff_all(data)
Value
tbl. The input data frame with the summary scores appended as
new columns.
Arguments
- data
tbl, Dataframe containing the columns to be summarized.